@@ -18,12 +18,12 @@ using namespace R;
 using namespace arma;
 extern "C" SEXP _rxCholInv(SEXP dms, SEXP theta, SEXP tn);
 
-//' Invert matrix using RcppArmadillo.  
+//' Invert matrix using RcppArmadillo.
 //'
 //' @param matrix matrix to be inverted.
-//' 
+//'
 //' @return inverse or pseudo inverse of matrix.
-//' 
+//'
 //' @export
 // [[Rcpp::export]]
 NumericVector rxInv(SEXP matrix){
@@ -33,7 +33,7 @@ NumericVector rxInv(SEXP matrix){
   success = inv(imat, smatrix);
   if (!success){
     imat = pinv(smatrix);
-    Rprintf(_("matrix seems singular; Using pseudo-inverse\n"));
+    Rprintf("%s", _("matrix seems singular; Using pseudo-inverse\n"));
   }
   NumericVector ret;
   ret = wrap(imat);
@@ -71,15 +71,15 @@ arma::mat rxToCholOmega(arma::mat cholMat){
 //'   [rxSymInvCholCreate()] with the default arguments and return a
 //'   reactive s3 object.  Otherwise, use the inversion object to
 //'   calculate the requested derivative/inverse.
-//' 
+//'
 //' @param theta Thetas to be used for calculation.  If missing (`NULL`), a
 //'     special s3 class is created and returned to access `Omega^1`
 //'     objects as needed and cache them based on the theta that is
 //'     used.
-//' 
+//'
 //' @param type The type of object.  Currently the following types are
 //'     supported:
-//' 
+//'
 //' * `cholOmegaInv` gives the
 //'     Cholesky decomposition of the Omega Inverse matrix.
 //' * `omegaInv` gives the Omega Inverse matrix.
@@ -88,18 +88,18 @@ arma::mat rxToCholOmega(arma::mat cholMat){
 //' * `d(D)` gives the `d(diagonal(Omega^-1))` with respect to
 //'     the theta parameter specified in the `thetaNumber`
 //'     parameter
-//' 
+//'
 //' @param thetaNumber For types `d(omegaInv)` and `d(D)`,
 //'     the theta number that the derivative is taken against.  This
 //'     must be positive from 1 to the number of thetas defining the
 //'     Omega matrix.
-//' 
+//'
 //' @return Matrix based on parameters or environment with all the
 //'     matrixes calculated in variables `omega`, `omegaInv`, `dOmega`,
 //'     `dOmegaInv`.
-//' 
+//'
 //' @author Matthew L. Fidler
-//' 
+//'
 //' @export
 // [[Rcpp::export]]
 RObject rxSymInvChol(RObject invObjOrMatrix, Nullable<NumericVector> theta = R_NilValue, std::string type = "cholOmegaInv", int thetaNumber = 0){
@@ -200,7 +200,7 @@ RObject rxSymInvCholEnvCalculate(List obj, std::string what, Nullable<NumericVec
       } else if (what == "chol.omega1"){
         rxSymInvCholEnvCalculate(obj, "chol.omegaInv", R_NilValue);
         arma::mat ret = rxToCholOmega(as<arma::mat>(e["chol.omegaInv"]));
-        e["chol.omega1"] = ret; 
+        e["chol.omega1"] = ret;
       } else if (what == "omega"){
         rxSymInvCholEnvCalculate(obj, "chol.omega1", R_NilValue);
         arma::mat U1 = as<mat>(e["chol.omega1"]);
